3.3.0
  - updated dependencies

3.2.2
  - update package info

3.2.1
  - fix faq url

3.2.0
  - added riskInBalancePercent metric to trades and open trades
  - added riskInPips metric to trades and open trades

3.1.2
  - fixed dependency vulnerabilities

3.1.1
  - added references to MT manager api and risk management api

3.1.0
  - added region support
  - breaking change: changed default value for update_history parameter get_account_trades method
  - improved readme and examples

2.0.0
  - added getAccountTrades method
  - added getAccountOpenTrades method
  - added freeMargin metric
  - added margin metric
  - added marginLevel metric
  - added cagr metric
  - added mar metric

1.0.4
  - updated dependencies

1.0.3
  - documentation clarifications for some metrics

1.0.0
  - Implemented MetaStats SDK
